@@ -1,9 +1,9 @@
-check_format_skat <- function(Z, SNPInfo, mod0, aggregateBy, snpNames) {
-	if(length(residuals(mod0)) != nrow(Z)) stop("Number of genotypes is not equal to number of phenotypes!")
+check_format_skat <- function(Z, SNPInfo, mod0, aggregateBy, snpNames, formula) {
+	if(length(stats::residuals(mod0)) != nrow(Z)) stop("Number of genotypes is not equal to number of phenotypes!")
 	
-	if(!is.null(na.action(mod0))){ 
+	if(!is.null(stats::na.action(mod0))){ 
 	  stop(paste0("Some observations in '", 
-	              capture.output(print(formula)), 
+	              utils::capture.output(print(formula)), 
 	              "' are missing...\n Complete data in the null model is required. Please remove, and subset genotypes accordingly"))
 	}
   
